Index: /issm/trunk-jpl/src/m/plot/plotdoc.py
===================================================================
--- /issm/trunk-jpl/src/m/plot/plotdoc.py	(revision 21288)
+++ /issm/trunk-jpl/src/m/plot/plotdoc.py	(revision 21289)
@@ -75,5 +75,19 @@
 						 'mask':" condition. Only 'true' values are plotted ",
 						 'log':" cutoff value for log",
-						 'backgroundcolor':" plot background color. RGB tuple or standard string"}
+						 'backgroundcolor':" plot background color. RGB tuple or standard string",
+                                                 'expdisp':" path (or list of paths) to the exp file to be plotted ",
+                                                 'explinewidth':" linewidth ",
+                                                 'explinestyle':" matplotlib linestyle string ",
+                                                 'explinecolor':" matplotlib color string ",
+                                                 'expfill':" (True/False) fill a closed contour ",
+                                                 'expfillcolor':" Color for a filled contour, only used if expfill is True ",
+                                                 'expfillalpha':" alpha transparency for filled contour ",
+                                                 'overlay':" True/False. Overlay a georeferenced image (radar/visible) ",
+                                                 'overlay_image':" path to overlay image ",
+                                                 'overlayhist':" plot a histogram of overlay image, used for setting overlaylims ",
+                                                 'overlaylims':" normalized limits to clip and stretch contrast of overlay image (in [0,1], ex. [0.25,0.75]) ",
+                                                 'alpha':" set transparency of plotted data (in [0,1]) "
+                                                 }
+
 	TODOoptions={'basin':" zoom on a given basin ('pineislandglacier','ronneiceshelf', use isbasin to identify a basin",
 					 'figurebackgroundcolor':" figure background color. (default is 'none',",
@@ -104,6 +118,4 @@
 					 'xticklabel':" specifiy xticklabel",
 					 'yticklabel':" specifiy yticklabel",
-					 'overlay':" yes or no. This will overlay a radar amplitude image behind",
-					 'overlay_image':" path to overlay image. provide overlay_xlim, overlay_ylim, overlay_xposting and overlay_yposting options also",
 					 'contrast':" (default 1) coefficient to add contrast to the radar amplitude image used in overlays",
 					 'highres':" resolution of overlayed radar amplitude image (default is 0, high resolution is 1).",
@@ -111,7 +123,5 @@
 					 'scaling':" scaling factor used by quiver plots. Default is 0.4",
 					 'autoscale':" set to 'off' to have all the quivers with the same size. Default is 'on'",
-					 'expprint':" plot exp file on top of a data plot. provide exp file as an argument (use a cell of strings if more than one)",
-					 'expstyle':" marker style for expprint plot (use a cell of strings if more than one)",
-					 'linewidth':" line width for expprint plot (use a cell of strings if more than one)",
+                                        					 'linewidth':" line width for expprint plot (use a cell of strings if more than one)",
 					 'border':" size of printlay border (in pixels). active only for overlay plots",
 
@@ -165,5 +175,5 @@
 	print("")
 	print("   The general look of the plot is then given by the following keywords")
-	for key in pyoptions.keys():
+	for key in sorted(pyoptions):
 		print("     - {} : {}".format(key,pyoptions[key]))
 	print("       any options (except 'data') can be followed by '#i' where 'i' is the subplot number, or '#all' if applied to all plots")

Index: /issm/trunk-jpl/src/m/plot/plot_overlay.py
===================================================================
--- /issm/trunk-jpl/src/m/plot/plot_overlay.py	(revision 21288)
+++ /issm/trunk-jpl/src/m/plot/plot_overlay.py	(revision 21289)
@@ -37,12 +37,12 @@
 		raise StandardError('overlay plot not supported for 3D meshes, project on a 2D layer first')
 
-	if not options.exist('geotiff_name'):
-		raise StandardError('overlay error: provide geotiff_name with path to geotiff file')
-	geotiff=options.getfieldvalue('geotiff_name')
+	if not options.exist('overlay_image'):
+		raise StandardError('overlay error: provide overlay_image with path to geotiff file')
+	image=options.getfieldvalue('overlay_image')
 
 	xlim=options.getfieldvalue('xlim',[min(md.mesh.x),max(md.mesh.x)])
 	ylim=options.getfieldvalue('ylim',[min(md.mesh.y),max(md.mesh.y)])
 
-	gtif=gdal.Open(geotiff)
+	gtif=gdal.Open(image)
 	trans=gtif.GetGeoTransform()
 	xmin=trans[0]
@@ -51,5 +51,5 @@
 	ymax=trans[3]
 	
 	# allow supplied geotiff to have limits smaller than basemap or model limits
 	x0=max(min(xlim),xmin)
 	x1=min(max(xlim),xmax)
@@ -57,5 +57,5 @@
 	y1=min(max(ylim),ymax)
 	inputname='temp.tif'
-	os.system('gdal_translate -quiet -projwin ' + str(x0) + ' ' + str(y1) + ' ' + str(x1) + ' ' + str(y0) + ' ' + geotiff + ' ' + inputname)
+	os.system('gdal_translate -quiet -projwin ' + str(x0) + ' ' + str(y1) + ' ' + str(x1) + ' ' + str(y0) + ' ' + image+ ' ' + inputname)
 	
 	gtif=gdal.Open(inputname)
@@ -51,5 +51,5 @@
 	ymax=trans[3]
 	
-	# allow supplied geotiff to have limits smaller than basemap or model limits
+	# allow supplied image to have limits smaller than basemap or model limits
 	x0=max(min(xlim),xmin)
 	x1=min(max(xlim),xmax)